package common.village;

import common.item.Item;
import common.item.ItemStack;
import common.tags.TagObject;

public class MerchantRecipe {
	private final ItemStack buying;
	private final ItemStack buySecond;
	private final ItemStack selling;

	public MerchantRecipe(TagObject tag) {
		this.buying = ItemStack.loadItemStackFromNBT(tag.getObject("buy"));
		this.selling = ItemStack.loadItemStackFromNBT(tag.getObject("sell"));
		this.buySecond = tag.hasObject("buyB") ? ItemStack.loadItemStackFromNBT(tag.getObject("buyB")) : null;
	}

	public MerchantRecipe(ItemStack buy1, ItemStack buy2, ItemStack sell) {
		this.buying = buy1;
		this.buySecond = buy2;
		this.selling = sell;
	}

	public MerchantRecipe(ItemStack buy, ItemStack sell) {
		this(buy, null, sell);
	}

	public MerchantRecipe(ItemStack buy, Item sell) {
		this(buy, new ItemStack(sell));
	}

	public ItemStack getBuying() {
		return this.buying;
	}

	public ItemStack getSecondBuy() {
		return this.buySecond;
	}

	public boolean hasSecondBuy() {
		return this.buySecond != null;
	}

	public ItemStack getSelling() {
		return this.selling;
	}

	public TagObject toNbt() {
		TagObject tag = new TagObject();
		tag.setObject("buy", this.buying.writeToNBT(new TagObject()));
		tag.setObject("sell", this.selling.writeToNBT(new TagObject()));
		if(this.buySecond != null)
			tag.setObject("buyB", this.buySecond.writeToNBT(new TagObject()));
		return tag;
	}
}
