package common.village;

import java.util.ArrayList;

import common.item.ItemStack;
import common.tags.Tag;
import common.tags.TagObject;
import common.tags.TagObjectList;

public class MerchantRecipeList extends ArrayList<MerchantRecipe> {
	public MerchantRecipe canUse(ItemStack stack1, ItemStack stack2, int index) {
		if(index > 0 && index < this.size()) {
			MerchantRecipe recipe = this.get(index);
			return !areItemsSimilar(stack1, recipe.getBuying())
					|| (stack2 != null || recipe.hasSecondBuy())
							&& (!recipe.hasSecondBuy() || !areItemsSimilar(stack2, recipe.getSecondBuy()))
					|| stack1.stackSize < recipe.getBuying().stackSize
					|| recipe.hasSecondBuy() && stack2.stackSize < recipe.getSecondBuy().stackSize ? null : recipe;
		}
		else {
			for(int z = 0; z < this.size(); z++) {
				MerchantRecipe recipe = this.get(z);
				if(areItemsSimilar(stack1, recipe.getBuying()) && stack1.stackSize >= recipe.getBuying().stackSize
						&& (!recipe.hasSecondBuy() && stack2 == null
								|| recipe.hasSecondBuy() && areItemsSimilar(stack2, recipe.getSecondBuy())
										&& stack2.stackSize >= recipe.getSecondBuy().stackSize)) {
					return recipe;
				}
			}
			return null;
		}
	}

	private static boolean areItemsSimilar(ItemStack stack1, ItemStack stack2) {
		return ItemStack.areItemsEqual(stack1, stack2)
				&& (!stack2.hasTagCompound() || stack1.hasTagCompound() && compareTags(stack2.getTagCompound(), stack1.getTagCompound()));
	}
	
	private static boolean compareTags(Tag tag1, Tag tag2) {
		if(tag1 == tag2 || tag1 == null)
			return true;
		else if(tag2 == null || !tag1.getClass().equals(tag2.getClass()))
			return false;
		else if(tag1 instanceof TagObject) {
			TagObject comp1 = (TagObject)tag1;
			TagObject comp2 = (TagObject)tag2;
			for(String key : comp1.getKeySet()) {
				Tag tag = comp1.get(key);
				if(!compareTags(tag, comp2.get(key)))
					return false;
			}
			return true;
		}
		return tag1.equals(tag2);
	}

	public void fromNbt(TagObjectList list) {
		this.clear();
		for(int z = 0; z < list.size(); z++) {
			this.add(new MerchantRecipe(list.get(z)));
		}
	}

	public TagObjectList toNbt() {
		TagObjectList list = new TagObjectList();
		for(int z = 0; z < this.size(); z++) {
			list.add(this.get(z).toNbt());
		}
		return list;
	}
}
